{% extends 'layouts/auth_base.html' %}
{% load static %}
{% block content %}
<!-- [ auth-signin ] start -->
<div class="auth-wrapper">
	<div class="auth-content">
		<div class="card">
			<div class="row align-items-center text-center">
				<div class="col-md-12">
					<div class="card-body">
						<img src="{% static 'assets/images/logo-dark.png' %}" alt="" class="img-fluid mb-4">
						<p class="login-box-msg">You are only one step a way from your new password, recover your password now.</p>
						<form method="post">
              {% csrf_token %}
              {% for field in form %}
              <div class="input-group mb-3">
                  <span class="input-group-text">
                    <i class="feather icon-lock"></i>
                  </span>
                {{field}}
              </div>
              <small class="text-danger">{{ field.errors }}</small>
              {% endfor %}
              <div class="row">
                <div class="col-12">
                  <button type="submit" class="btn btn-primary btn-block">Change password</button>
                </div>
                <!-- /.col -->
              </div>
            </form>
            <p class="mt-3 mb-1">
              <a href="{% url 'auth_signin' %}">Login</a>
            </p>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
<!-- [ auth-signin ] end -->
{% endblock content %}