<div class="page-header">
    <div class="page-block">
        <div class="row align-items-center">
            <div class="col-md-12">
                <div class="page-header-title">
                    <h5 class="m-b-10">Radial Chart</h5>
                </div>
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="{% url 'index' %}"><i class="feather icon-home"></i></a></li>
                    <li class="breadcrumb-item"><a href="#">Chart</a></li>
                    <li class="breadcrumb-item"><a href="#">Radial Chart</a></li>
                </ul>
            </div>
        </div>
    </div>
</div>