<nav class="pcoded-navbar menupos-fixed menu-light ">
    <div
        class="navbar-wrapper  ">
        <div class="navbar-content scroll-div">
            {% include 'includes/menu-list.html' %}
            <div class="card text-center">
                <div class="card-body px-3">
                    <i class="feather icon-sunset f-40"></i>
                    <h6 class="mt-3">Upgrade to Pro</h6>
                    <p>To get more features and components</p>
                    <a href="https://appseed.us/product/gradient-able/django/" target="_blank"
                        class="btn btn-primary btn-sm text-white m-0">Download</a>
                </div>
            </div>
        </div>
    </div>
</nav>