{% load static %}
<header class="navbar pcoded-header navbar-expand-lg navbar-light headerpos-fixed header-blue">
    <div class="m-header">
        <a class="mobile-menu" id="mobile-collapse" href="#"><span></span></a>
        <a href="#" class="b-brand">
            <!-- ========   change your logo hear   ============ -->
            <img src="{% static 'assets/images/logo.png' %}" alt="" class="logo">
            <img src="{% static 'assets/images/logo-icon.png' %}" alt="" class="logo-thumb">
        </a>
        <a href="#" class="mob-toggler">
            <i class="feather icon-more-vertical"></i>
        </a>
    </div>
    <div class="collapse navbar-collapse">
        <ul class="navbar-nav me-auto">
            <li class="nav-item">
                <a href="#" class="pop-search"><i class="feather icon-search"></i></a>
                <div class="search-bar">
                    <input type="text" class="form-control border-0 shadow-none" placeholder="Search here">
                    <button type="button" class="btn-close" aria-label="Close">
                    </button>
                </div>
            </li>
        </ul>
        <ul class="navbar-nav ms-auto">
            <li>
                <div class="dropdown drp-user">
                    <a href="#" class="dropdown-toggle" data-bs-toggle="dropdown">
                        <img src="{% static 'assets/images/user/avatar-1.jpg' %}" class="img-radius wid-40"
                            alt="User-Profile-Image">
                    </a>
                    <div class="dropdown-menu dropdown-menu-end profile-notification">
                        <div class="pro-head">
                            <img src="{% static 'assets/images/user/avatar-1.jpg' %}" class="img-radius"
                                alt="User-Profile-Image">
                            <span>John Doe</span>
                        </div>
                        <ul class="pro-body">
                            <li class="bg-transparent mb-2 ms-3">
                                <a target="_blank" href="https://appseed.us/support/">
                                    <span class="badge bg-primary">Support</span>
                                </a>
                            </li>
                            {% if request.user.is_authenticated %}
                                {% if request.user.is_superuser %}
                                <li><a href="{% url 'admin:password_change' %}" class="dropdown-item">
                                    <i class="feather icon-lock"></i> Change Password</a></li>
                                <li><a href="{% url 'admin:logout' %}" class="dropdown-item"><i
                                            class="feather icon-lock"></i> Logout</a></li>
                                {% else %}
                                <li><a href="{% url 'password_change' %}" class="dropdown-item">
                                    <i class="feather icon-lock"></i> Change Password</a></li>
                                <li><a href="{% url 'logout' %}" class="dropdown-item"><i
                                            class="feather icon-lock"></i> Logout</a></li>
                                {% endif %}                            
                            {% else %}
                                <li><a href="{% url 'auth_signin' %}" class="dropdown-item"><i
                                    class="feather icon-log-in"></i> Sign IN</a></li>
                            {% endif %}
                        </ul>
                    </div>
                </div>
            </li>
        </ul>
    </div>
    

</header>