<!DOCTYPE html>
{% load static %}
<html lang="en">
<head>
  {% include 'includes/head.html' %}
  {% block extrastyle %}{% endblock extrastyle %}
</head>
<body class="{% block bodyclass %}{% endblock bodyclass %}">

  {% block content %}{% endblock content %}

  {% include 'includes/scripts.html' %}
  {% block scripts %}
  <script src="{% static 'assets/js/vendor-all.min.js' %}"></script>
  <script src="{% static 'assets/js/plugins/bootstrap.min.js' %}"></script>
  <script src="{% static 'assets/js/waves.min.js' %}"></script>
  {% endblock scripts %}

</body>
</html>
