# -*- encoding: utf-8 -*-
"""
Copyright (c) 2019 - present AppSeed.us
"""

from django.apps import AppConfig

class AdminGradientConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'admin_gradient'