{% extends 'layouts/auth_base.html' %}
{% load static %}
{% block content %}
<!-- [ auth-signin ] start -->
<div class="auth-wrapper">
	<div class="auth-content">
		<div class="card">
			<div class="row align-items-center text-center">
				<div class="col-md-12">
					<div class="card-body">
						<img src="{% static 'assets/images/logo-dark.png' %}" alt="" class="img-fluid mb-4">
						<h4 class="mb-3 f-w-400">Signin</h4>
						<form method="post">
							{% csrf_token %}
							{% if form.non_field_errors %}
							{% for error in form.non_field_errors  %}
								<small class="text-danger mb-3">{{ error }}</small>
							{% endfor %}
							{% endif %}
							{% for field in form %}
							<div class="input-group mb-3">
								<span class="input-group-text">
									<i class="feather {% if field.name == 'username' %} icon-user {% else %}  icon-lock {% endif %}"></i>
								</span>
								{{field}}
							</div>
							<small class="text-danger">{{ field.errors }}</small>
       						 {% endfor %}
							<div class="form-group text-left mt-2">
								<div class="checkbox checkbox-primary d-inline">
									<input type="checkbox" name="checkbox-fill-1" id="checkbox-fill-a1" checked="">
									<label for="checkbox-fill-a1" class="cr"> Save credentials</label>
								</div>
							</div>
							<button class="btn btn-block btn-primary mt-2 mb-4">Signin</button>
							<p class="mb-2 text-muted">Forgot password? <a href="{% url 'forgot_password' %}" class="f-w-400">Reset</a></p>
							<p class="mb-0 text-muted">Don’t have an account? <a href="{% url 'auth_signup' %}" class="f-w-400">Signup</a></p>
						</form>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
<!-- [ auth-signin ] end -->
{% endblock content %}
