{% extends 'layouts/auth_base.html' %}
{% load static %}
{% block title %} Email sent {% endblock title %}

{% block bodyclass %} login-page {% endblock bodyclass %}

{% block content %}
<div class="auth-wrapper">
	<div class="auth-content">
		<div class="card">
			<div class="row align-items-center text-center">
				<div class="col-md-12">
					<div class="card-body">
						<img src="{% static 'assets/images/logo-dark.png' %}" alt="" class="img-fluid mb-4">
                <p class="login-box-msg">An email has been sent to your email address. Please click the link and reset your password.</p>
                <p class="mt-3 mb-1">
                  <a href="{% url 'auth_signin' %}">Login</a>
                </p>
                <p class="mb-0">
                  <a href="{% url 'auth_signup' %}" class="text-center">Register a new membership</a>
                </p>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>

{% endblock %}
