<!DOCTYPE html>
<html lang="en">
<head>
{% include 'includes/head.html' %}
{% block extrastyle %}{% endblock extrastyle %}
</head>
<body>
    {% block pre_loader %}
        {% include 'includes/pre-loader.html' %}
    {% endblock pre_loader %}

    {% block sidebar %}
        {% include 'includes/sidebar.html' %}
    {% endblock sidebar %}

    {% block navigation %}
        {% include 'includes/navigation.html' %}
    {% endblock navigation %}

    <!-- [ Main Content ] start -->
    <section class="pcoded-main-container">
        <div class="pcoded-content">
            {% comment %} {% block breadcrumbs %}
                {% include 'includes/breadcrumbs.html' %}
            {% endblock breadcrumbs %} {% endcomment %}

            {% block content %}{% endblock content %}
        </div>
    </section>

    {% include 'includes/scripts.html' %}
    {% block extrajs %}{% endblock extrajs %}
</body>
</html>