   {% load static %}
   <!-- Required Js -->
    <script src="{% static 'assets/js/plugins/popper.min.js' %}"></script>
    <script src="{% static 'assets/js/plugins/perfect-scrollbar.min.js' %}"></script>
    <script src="{% static 'assets/js/plugins/bootstrap.min.js' %}"></script>
    <script src="{% static 'assets/js/pcoded.js' %}"></script>
