{% extends 'layouts/auth_base.html' %}
{% load static %}
{% block content %}
<div class="auth-wrapper">
	<div class="auth-content">
		<div class="card">
			<div class="row align-items-center text-center">
				<div class="col-md-12">
					<div class="card-body">
						<img src="{% static 'assets/images/logo-dark.png' %}" alt="" class="img-fluid mb-4">
              <p class="login-box-msg">Your password has been changed successfully.</p>
              <a href="/">Go to dashboard</a>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
{% endblock content %}